# [genice2_vpython](https://github.com/vitroid/genice-vpython/)

A [GenIce2](https://github.com/vitroid/GenIce) plugin to visualize the structure with [VPython](http://vpython.org).

version 0.5.1

## Requirements


* vpython
* genice2>=2.1
* countrings>=0.1.7

## Installation from PyPI

```shell
% pip install genice2_vpython
```

## Manual Installation

### System-wide installation

```shell
% make install
```

### Private installation

Copy the files in genice2_vpython/formats/ into your local formats/ folder.

## Usage
        

## Test in place

```shell
% make test
```
